@@ -8,6 +8,7 @@ Database structure:
                 "{player-uid}": {
                     "uid": "{player-uid}",
                     "cartridge": "pokemon_red",
+                    "color": "#F33F19",
                 }
             },
             "events": {
@@ -28,15 +29,10 @@ Database structure:
 
 from typing import List, Set
 
-from pyrebase import initialize_app
 from pyrebase.pyrebase import Database
 
-from gateau_api.constants import (
-    FIREBASE_API_KEY,
-    FIREBASE_AUTH_DOMAIN,
-    FIREBASE_DATABASE_URL,
-    FIREBASE_STORAGE_BUCKET,
-)
+from gateau_api.exceptions import PlayerNotFound
+from gateau_api.firebase import pyrebase_app
 from gateau_api.game_ram.cartridge_info import ChangeMeaning
 from gateau_api.game_ram.carts import cart_info
 from gateau_api.types import GameEvent, Player, RamChangeInfo
@@ -47,17 +43,12 @@ class GateauFirebaseService:
     Service for Gateau games stored in Firebase's realtime database
     """
 
-    def __init__(self):
-        firebase = initialize_app(
-            {
-                "databaseURL": FIREBASE_DATABASE_URL,
-                "apiKey": FIREBASE_API_KEY,
-                "authDomain": FIREBASE_AUTH_DOMAIN,
-                "storageBucket": FIREBASE_STORAGE_BUCKET,
-            }
-        )
+    def __init__(self, id_token: str):
+        firebase = pyrebase_app()
         self.root = firebase.database()
 
+        self.id_token = id_token
+
     def games_db(self) -> Database:
         """
         Reference to the games db
@@ -99,21 +90,31 @@ class GateauFirebaseService:
         Get a player
         """
         db = self.player_db(game_id=game_id, player_id=player_id)
-        return Player.parse_obj(db.get().val())
+        result = db.get(token=self.id_token).val()
+        if result is None:
+            raise PlayerNotFound(f"No player with UID {player_id} in game {game_id}")
+        return Player.parse_obj(result)
 
     def set_player(self, game_id: str, player: Player):
         """
         Set a player in the DB
         """
         db = self.players_db(game_id=game_id)
-        db.child(player.uid).set(player.dict())
+        db.child(player.uid).set(player.dict(), token=self.id_token)
+
+    def remove_player(self, game_id: str, player_id: str):
+        """
+        Remove a player from a game
+        """
+        db = self.players_db(game_id=game_id)
+        db.child(player_id).remove(token=self.id_token)
 
     def get_subscriptions(self, game_id) -> Set[str]:
         """
         Get subscriptions by meaning
         """
         db = self.subscriptions_db(game_id=game_id)
-        subscriptions = db.get().val()
+        subscriptions = db.get(token=self.id_token).val()
         return {key for key, value in subscriptions.items() if value}
 
     def add_subscriptions(self, game_id: str, meanings: Set[str]):
@@ -122,14 +123,17 @@ class GateauFirebaseService:
         """
         for meaning in meanings:
             db = self.subscriptions_db(game_id=game_id)
-            db.child(meaning).set(True)
+            db.child(meaning).set(True, token=self.id_token)
 
     def get_events(self, game_id: str) -> List[GameEvent]:
         """
         Get events from a game, in chronological order
         """
         db = self.events_db(game_id=game_id)
-        events = [GameEvent.parse_obj(event) for event in db.get().val().values()]
+        events = [
+            GameEvent.parse_obj(event)
+            for event in db.get(token=self.id_token).val().values()
+        ]
         return sorted(events, key=lambda e: e.timestamp)
 
     def add_event(self, game_id: str, event: GameEvent):
@@ -137,7 +141,7 @@ class GateauFirebaseService:
         Push a new game event
         """
         db = self.events_db(game_id=game_id)
-        db.push(event.dict())
+        db.push(event.dict(), token=self.id_token)
 
     def get_ram_subscriptions(self, game_id: str, player_id: str) -> Set[int]:
         """
@@ -146,6 +150,8 @@ class GateauFirebaseService:
         """
         subscriptions = self.get_subscriptions(game_id=game_id)
         player = self.get_player(game_id=game_id, player_id=player_id)
+        if not player:
+            raise
         info = cart_info(player.cartridge)
         ram_addresses = {info.byte_for_meaning(meaning) for meaning in subscriptions}
 
